==> excellent_loading-1.0.0.tar.gz: lib/loading.dart <==
// The MIT License (MIT)
//
// Copyright (c) 2020 nslogx
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
// IN THE SOFTWARE.
import 'package:excellent_loading/flutter_excellentloading.dart';
import 'package:flutter/material.dart';

import './overlay_entry.dart';

class FlutterExcellentLoading extends StatefulWidget {
  final Widget? child;

  const FlutterExcellentLoading({
    Key? key,
    required this.child,
  })  : assert(child != null),
        super(key: key);

  @override
  FlutterExcellentLoadingState createState() => FlutterExcellentLoadingState();
}

class FlutterExcellentLoadingState extends State<FlutterExcellentLoading> {
  late ExcellentLoadingOverlayEntry _overlayEntry;

  @override
  void initState() {
    super.initState();
    _overlayEntry = ExcellentLoadingOverlayEntry(
      builderx: (BuildContext context) => ExcellentLoading.instance.w ?? Container(),
    );
    ExcellentLoading.instance.overlayEntry = _overlayEntry;
  }

  @override
  Widget build(BuildContext context) {
    return Material(
      child: Overlay(
        initialEntries: [
          ExcellentLoadingOverlayEntry(
            builderx: (BuildContext context) {
              if (widget.child != null) {
                return widget.child!;
              } else {
                return Container();
              }
            },
          ),
          _overlayEntry,
        ],
      ),
    );
  }
}

==> excellent_loading-1.0.3.tar.gz: lib/loading.dart <==
// The MIT License (MIT)
//
// Copyright (c) 2020 nslogx
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
// IN THE SOFTWARE.
import 'package:excellent_loading/flutter_excellentloading.dart';
import 'package:flutter/material.dart';

import './overlay_entry.dart';

class FlutterExcellentLoading extends StatefulWidget {
  final Widget? child;

  const FlutterExcellentLoading({
    Key? key,
    required this.child,
  })  : assert(child != null),
        super(key: key);

  @override
  FlutterExcellentLoadingState createState() => FlutterExcellentLoadingState();
}

class FlutterExcellentLoadingState extends State<FlutterExcellentLoading> {
  late ExcellentLoadingOverlayEntry _overlayEntry;

  @override
  void initState() {
    super.initState();
    _overlayEntry = ExcellentLoadingOverlayEntry(
      builderx: (BuildContext context) =>
          ExcellentLoading.instance.w ?? Container(),
    );
    ExcellentLoading.instance.overlayEntry = _overlayEntry;
  }

  @override
  Widget build(BuildContext context) {
    return Material(
      child: Overlay(
        initialEntries: [
          ExcellentLoadingOverlayEntry(
            builderx: (BuildContext context) {
              if (widget.child != null) {
                return widget.child!;
              } else {
                return Container();
              }
            },
          ),
          _overlayEntry,
        ],
      ),
    );
  }
}
